aboutsummaryrefslogtreecommitdiffstats
path: root/interior.go
diff options
context:
space:
mode:
Diffstat (limited to 'interior.go')
-rw-r--r--interior.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/interior.go b/interior.go
index b1cdce7..98ff4d2 100644
--- a/interior.go
+++ b/interior.go
@@ -34,8 +34,8 @@ type validateInteriorBasicReq struct {
SrcUrl string `json:"source_url"`
}
-// InteriorValidationRecord contains the validation status of an interior file.
-type InteriorValidationRecord struct {
+// InteriorValidation contains the validation status of an interior file.
+type InteriorValidation struct {
Id uint
SrcUrl string `json:"source_url"`
NPages uint `json:"page_count"`